.. code-block:: bash

    pip install revy


Documentation
=====================================

.. toctree::
   :maxdepth: 2

   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
